import Vue from 'vue'
import App from './App.vue'
import router from './router'
import store from './store'
import cloneDeep from 'lodash/cloneDeep'
import VueCookie from 'vue-cookie'
import refreshTitle from './utils/refreshTitle'
import './utils/filter'
import './assets/styles/icon.scss'
// 全站配置
window.SITE_CONFIG = {}
Vue.prototype.$refreshTitle = refreshTitle
Vue.directive('myBlur', {
  inserted: function (element) {
    element.onblur = function () {
      const timer = setTimeout(function () {
        clearTimeout(timer)
        const scrollHeight = document.documentElement.scrollTop || document.body.scrollTop || 0
        window.scrollTo(0, Math.max(scrollHeight - 1, 0))
      }, 100)
    }
  }
})

Vue.use(VueCookie)
Vue.config.ignoredElements = ['wx-open-launch-weapp']

new Vue({
  router,
  store,
  render: h => h(App),
  created () {
    // 保存整站vuex本地储存初始状态
    window.SITE_CONFIG.storeState = cloneDeep(store.state)
    this.reloadInWX()
  },
  methods: {
    /**
     * 处理微信内二次分享
     */
    reloadInWX () {
      let href = decodeURIComponent(window.location.href)
      // 微信环境二次分享
      if (href.indexOf('groupmessage') > -1 || href.indexOf('singlemessage') > -1 || href.indexOf('timeline') > -1 || href.indexOf('isappinstalled') > -1) {
        href = href.replace(/from=(groupmessage|singlemessage|timeline|isappinstalled)(\S*)/, '')
        location.replace(href)
        location.reload(true)
      }
    }
  }
}).$mount('#app')
