import Vue from 'vue'
import VueRouter from 'vue-router'
import { updateWechatToken, updateInviteId } from '@/utils'

Vue.use(VueRouter)

const _import = require('./import-' + process.env.NODE_ENV)
const routes = [
  // {
  //   path: '*',
  //   redirect: '/404'
  // },
  {
    path: '/404',
    name: '404',
    component: _import('page/404/index')
  },
  {
    path: '/',
    component: _import('views/marketing/index'),
    children: [
      {
        path: '', // 省钱
        name: 'MarketingSave',
        component: _import('views/marketing/save/index'),
        meta: {
          showTabbar: true,
          isUseCache: false,
          keepAlive: true
        }
      },
      {
        path: '/return', // 返钱
        name: 'MarketingReturn',
        component: _import('views/marketing/return/index'),
        meta: {
          showTabbar: true,
          isUseCache: false,
          keepAlive: true
        }
      },
      {
        path: '/make', // 赚钱
        name: 'MarketingMake',
        component: _import('views/marketing/make/index'),
        meta: {
          showTabbar: true,
          isUseCache: false,
          keepAlive: true
        }
      }
    ]
  },
  {
    path: '/invite', // 我的
    name: 'Invite',
    component: _import('views/invite/index'),
    meta: {
      showTabbar: true,
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/mine', // 我的
    name: 'Mine',
    component: _import('views/mine/index'),
    meta: {
      showTabbar: true,
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/recommend', // 分享海报
    name: 'Recommend',
    component: _import('views/recommend/index'),
    meta: {
      isUseCache: false,
      keepAlive: false
    }
  },
  {
    path: '/wallet', // 我的钱包
    name: 'Wallet',
    component: _import('views/wallet/index'),
    meta: {
      isUseCache: false,
      keepAlive: false
    }
  },
  {
    path: '/withdrawCash', // 提现
    name: 'WithdrawCash',
    component: _import('views/withdrawCash/index'),
    meta: {
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/bill', // 收支明细
    name: 'Bill',
    component: _import('views/bill/index'),
    meta: {
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/order', // 下单记录
    name: 'Order',
    component: _import('views/order/index'),
    meta: {
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/fans', // 粉丝
    name: 'Fans',
    component: _import('views/fans/index'),
    meta: {
      isUseCache: false,
      keepAlive: true
    }
  },
  {
    path: '/paymentCode', // 支付码
    name: 'PaymentCode',
    component: _import('views/paymentCode/index'),
    meta: {
      isUseCache: false,
      keepAlive: false
    }
  },
  {
    path: '/shareMiddle', // 分享中间页
    name: 'ShareMiddle',
    component: _import('views/shareMiddle/index'),
    meta: {
      isUseCache: false,
      keepAlive: false
    }
  },
  {
    path: '/category', // 分类
    component: _import('views/category/index'),
    children: [
      {
        path: '',
        name: 'CategoryIndex',
        component: _import('views/category/index/index'),
        meta: {
          isUseCache: false,
          keepAlive: true
        }
      },
      {
        path: '/detail',
        name: 'CategoryDetail',
        component: _import('views/category/detail/index'),
        meta: {
          isUseCache: false,
          keepAlive: true
        }
      }
    ]
  }
]

const router = new VueRouter({
  mode: 'history',
  routes,
  scrollBehavior (to, from, savedPosition) {
    if (to.hash) {
      return {
        selector: to.hash
      }
    }
    // keep-alive 返回缓存页面后记录浏览位置
    if (savedPosition && to.meta.keepAlive) {
      return savedPosition
    }
    // 异步滚动操作
    return new Promise((resolve) => {
      setTimeout(() => {
        resolve({ x: 0, y: 1 })
      }, 0)
    })
  }
})
const originalPush = VueRouter.prototype.push

VueRouter.prototype.push = function push (location, onResolve, onReject) {
  if (onResolve || onReject) return originalPush.call(this, location, onResolve, onReject)
  return originalPush.call(this, location).catch(err => err)
}

router.beforeEach((to, from, next) => {
  updateWechatToken()
  updateInviteId()
  next()
})

export default router
